Skip to contents

Extracts coefficients from a glmsusie model fit by summing the coefficients across all single effects for each predictor.

Usage

# S3 method for class 'glmsusie'
coef(object, intercept = FALSE, ...)

Arguments

object

A fitted model object of class "glmsusie".

intercept

Logical; if TRUE, include the intercept term as the first element of the returned vector. Default is FALSE.

...

Additional arguments (not used).

Value

A numeric vector of coefficients, with names corresponding to the column names of the design matrix. If intercept = TRUE, the first element will be named "(Intercept)".